@@ -245,7 +245,7 @@ def find_patterns(file):
     return outTuple
 
 
-def set_model_params():
+def set_model_params(X, y):
     model = Sequential()
     model.add(LSTM(256, input_shape=(X.shape[1], X.shape[2]), return_sequences=True))
     model.add(Dropout(0.2))
